import React, { useState } from 'react';
import { View, Text, StyleSheet, Image, TextInput, TouchableWithoutFeedback, Keyboard, TouchableOpacity, Modal } from 'react-native';
import { rpx } from '../../utils/rpx';

const AddShare = () => {
    const [phone, setPhone] = useState('');
    const [name, setName] = useState('');
    const [time, setTime] = useState('');
    const [showTimeModal, setShowTimeModal] = useState(false);
    const [showBleInfo, setShowBleInfo] = useState(false);
    const timeOptions = ['1天', '7天', '30天', '永久'];
    const [allowBleLocation, setAllowBleLocation] = useState(true);
    const handlePress = () => {
        setShowTimeModal(true);
    }
    return (
        <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
            <View style={styles.container}>
                <View style={styles.IptBox}>
                    <TextInput
                        style={styles.input}
                        placeholder="共享人手机号"
                        value={phone}
                        onChangeText={setPhone}
                    />
                    <Image
                        source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uMSABuH69gxKXIP0zqtl' }}
                        style={styles.phoneImg}
                    />
                </View>
                <View style={styles.IptBox}>
                    <TextInput
                        style={styles.input}
                        placeholder="共享人姓名"
                        value={name}
                        onChangeText={setName}
                    />
                </View>
                <TouchableOpacity onPress={handlePress} activeOpacity={1}>
                    <View style={styles.IptBox}>
                        <TextInput
                            style={styles.input}
                            placeholder="共享钥匙有效期"
                            value={time}
                            onChangeText={setTime}
                            editable={false}
                        />
                        <Image
                            source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uGq4yJlU1ZZRkwiJ8Y74' }}
                            style={styles.phoneImg}
                        />
                    </View>
                </TouchableOpacity>
                <TouchableOpacity style={styles.bleInfo} onPress={() => setShowBleInfo(true)}>
                    <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uvjPwfAKsL9kHD1Tb9aW' }} style={styles.bleImg}></Image>
                    <View style={styles.bleInfoBox}>
                        <Text style={styles.tit}>上次蓝牙连接位置</Text>
                        <Text style={[
                            styles.txt,
                            { color: allowBleLocation ? '#4297F3' : '#666' }
                        ]}>
                            {allowBleLocation ? '允许' : '不允许'}
                        </Text>
                    </View>

                </TouchableOpacity>
                <Modal visible={showBleInfo} transparent={true} animationType="slide">
                    <View style={styles.modalContainers}>
                        <View style={styles.modalContents}>
                            <Image
                                source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uwMP7N2hCLFdwwDPhHMm' }}
                                style={styles.bleLocationImg}
                            />
                            <Text style={styles.bleModalTitle}>
                                是否允许租赁人查看{'\n'}上次蓝牙连接位置
                            </Text>

                            <View style={styles.radioGroup}>
                                <TouchableOpacity
                                    style={styles.radioItem}
                                    onPress={() => setAllowBleLocation(true)}
                                >
                                    <Text style={styles.radioText}>允许</Text>
                                    <View style={styles.radioCircle}>
                                        {allowBleLocation && <View style={styles.radioSelected} />}
                                    </View>
                                   
                                </TouchableOpacity>
                                <View style={styles.line}></View>
                                <TouchableOpacity
                                    style={styles.radioItem}
                                    onPress={() => setAllowBleLocation(false)}
                                >
                                      <Text style={styles.radioText}>不允许</Text>
                                    <View style={styles.radioCircle}>
                                        {!allowBleLocation && <View style={styles.radioSelected} />}
                                    </View>
                                  
                                </TouchableOpacity>
                            </View>

                            <TouchableOpacity
                                style={styles.confirmButton}
                                onPress={() => setShowBleInfo(false)}
                            >
                                <Text style={styles.confirmButtonText}>确定</Text>
                            </TouchableOpacity>
                        </View>
                    </View>
                </Modal>
                <Modal
                    visible={showTimeModal}
                    transparent={true}
                    animationType="slide"
                >
                    <View style={styles.modalContainer}>
                        <View style={styles.modalContent}>
                            <View style={styles.modalHeader}>
                                <TouchableOpacity
                                    style={styles.headerButton}
                                    onPress={() => setShowTimeModal(false)}
                                >
                                    <Text style={styles.cancelText}>取消</Text>
                                </TouchableOpacity>
                                <Text style={styles.modalTitle}>选择有效期</Text>
                                <TouchableOpacity
                                    style={styles.headerButton}
                                    onPress={() => setShowTimeModal(false)}
                                >
                                    <Text style={styles.confirmText}>确定</Text>
                                </TouchableOpacity>
                            </View>
                          
                            <View style={styles.optionsContainer}>
                                {timeOptions.map((option, index) => (
                                    <TouchableOpacity
                                        key={index}
                                        style={[
                                            styles.optionItem,
                                            time === option && styles.selectedItemBg
                                        ]}
                                        onPress={() => {
                                            setTime(option);
                                            setShowTimeModal(false);
                                        }}
                                    >
                                        <Text style={[
                                            styles.optionText,
                                            time === option && styles.selectedOption
                                        ]}>
                                            {option}
                                        </Text>
                                    </TouchableOpacity>
                                ))}
                            </View>
                        </View>
                    </View>
                </Modal>
            </View>
        </TouchableWithoutFeedback>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: '#F3FCFF',
        alignItems: 'center',
    },
    modalContainers: {
        flex: 1,
        justifyContent: 'center',
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
        paddingHorizontal: rpx(30),
    },
    modalContents: {
        backgroundColor: '#fff',
        borderRadius: rpx(20),
        alignItems: 'center',
        paddingVertical: rpx(40),
        padding:rpx(28)
    },
    bleLocationImg: {
        width: rpx(338),
        height: rpx(338),
        marginBottom: rpx(30),
    },
    bleModalTitle: {
        fontSize: rpx(36),
        color: '#333',
        textAlign: 'center',
        lineHeight: rpx(50),
        marginBottom: rpx(40),
    },
    line: {
        borderWidth: rpx(1),
        borderColor: '#eee',
        marginBottom: rpx(28)
    },
    radioGroup: {
        width: '100%',
        paddingHorizontal: rpx(60),
        marginBottom: rpx(40),
        borderWidth: rpx(2),
        borderColor: '#eee',
        borderRadius: rpx(30),
        paddingTop: rpx(28)
    },
    radioItem: {
        
        justifyContent: 'space-between',
        flexDirection: 'row',
        alignItems: 'center',
        marginBottom: rpx(30),
    },
    radioCircle: {
        width: rpx(44),
        height: rpx(44),
        borderRadius: rpx(22),
        borderWidth: rpx(2),
        borderColor: '#4297F3',
        marginRight: rpx(20),
        justifyContent: 'center',
        alignItems: 'center',
    },
    radioSelected: {
        width: rpx(28),
        height: rpx(28),
        borderRadius: rpx(14),
        backgroundColor: '#4297F3',
    },
    radioText: {
        fontSize: rpx(32),
        color: '#333',
    },
    confirmButton: {
        width: rpx(560),
        height: rpx(88),
        backgroundColor: '#4297F3',
        borderRadius: rpx(44),
        justifyContent: 'center',
        alignItems: 'center',
    },
    confirmButtonText: {
        fontSize: rpx(32),
        color: '#fff',
        fontWeight: '500',
    },
    bleImg: {
        width: rpx(88),
        height: rpx(88),
    },
    tit: {
        fontSize: rpx(36),
        color: '#1E1D20',
    },
    txt: {
        fontSize: rpx(36),
        color: '#4297F3',
    },
    bleInfo: {
        marginTop: rpx(30),
        width: rpx(688),
        height: rpx(174),
        backgroundColor: '#ffffff',
        padding: rpx(44),
        flexDirection: 'row',
        // alignItems: 'center',
        // justifyContent: 'center',
    },
    bleInfoBox: {
        paddingLeft: rpx(20),
    },
    modalContainer: {
        flex: 1,
        justifyContent: 'flex-end',
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
    },
    modalContent: {
        backgroundColor: '#fff',
        borderTopLeftRadius: rpx(20),
        borderTopRightRadius: rpx(20),
        paddingBottom: rpx(30),
    },
    modalHeader: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        height: rpx(100),
        borderBottomWidth: 1,
        borderBottomColor: '#eee',
        paddingHorizontal: rpx(30),
    },
    headerButton: {
        padding: rpx(20),
    },
    modalTitle: {
        fontSize: rpx(32),
        fontWeight: '500',
        color: '#333',
    },
    cancelText: {
        fontSize: rpx(32),
        color: '#666',
    },
    confirmText: {
        fontSize: rpx(32),
        color: '#4297F3',
    },
    optionsContainer: {
        paddingHorizontal: rpx(30),
        paddingTop: rpx(20),
        alignItems: 'center',
    },
    optionItem: {
        height: rpx(100),
        width: rpx(300),
        justifyContent: 'center',
        alignItems: 'center',
        // paddingLeft: rpx(30),
        borderRadius: rpx(16),
        marginBottom: rpx(20),
    },
    optionText: {
        fontSize: rpx(32),
        color: '#333',
    },
    selectedItemBg: {
        backgroundColor: '#F0F7FF',
    },
    selectedOption: {
        color: '#4297F3',
    },
    IptBox: {
        marginTop: rpx(30),
        paddingHorizontal: rpx(30),
        width: rpx(688),
        height: rpx(128),
        flexDirection: 'row',
        alignItems: 'center',
        backgroundColor: '#ffffff',
        borderRadius: rpx(30),

    },
    input: {
        flex: 1,
        fontSize: rpx(36),
    },
    phoneImg: {
        width: rpx(54),
        height: rpx(54),
    }
})
export default AddShare;