import React, { useState } from 'react';
import { View, Text, StyleSheet, ScrollView, Image, TouchableOpacity } from 'react-native';
import { useNavigation } from '@react-navigation/native';
import { rpx } from '../../utils/rpx';

type CarItem = {
  id: number;
  title: string;
  model: string;
  status: string;
  isShared: boolean;
};

export default function DeviceList() {
  const navigation = useNavigation();
  const [selectedItem, setSelectedItem] = useState<number | null>(null);
  const handlePress = () => {
     
    navigation.navigate('BindIndex' as never);
    // console.log(navigation);
};

const handleCancel = () => {
  navigation.goBack();
};

  // 示例数据保持不变
  const carList: CarItem[] = [
    
    {
      id: 1,
      title: '备注1376',
      model: '车型：飞过的魔毯不须归于温暖',
      status: '车辆登入X小时出租',
      isShared: false,
    },
    {
      id: 2,
      title: '备注1376',
      model: '车型：飞过的魔毯不须归于温暖',
      status: '车辆登入X小时出租',
      isShared: true,
    },
  ];

  const toggleSelect = (id: number) => {
    setSelectedItem(prev => prev === id ? null : id);
  };

  const renderCarItem = (item: CarItem) => (
    <View key={item.id} style={[styles.carItem, item.id !== 1 && styles.marginTop]}>
      <View style={styles.leftContent}>
        <Text style={styles.title}>{item.title}</Text>
        <Text style={styles.subTitle}>{item.model}</Text>
        <Text style={styles.status}>{item.status}</Text>
        <Text style={[styles.tag, item.isShared && styles.tagShare]}>
          {item.isShared ? '临时共享' : '车主'}
        </Text>
      </View>
      <View style={styles.rightContent}>
        <Image 
          source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uVnIDwcwQP7oo12PeYVJ' }} 
          style={styles.carImage} 
        />
        <View style={styles.checkboxWrapper}>
          <Text style={styles.checkboxText}>选择车辆</Text>
          <TouchableOpacity 
            onPress={() => toggleSelect(item.id)}
            style={styles.checkboxContainer}
          >
            <Image 
              source={{ 
                uri: selectedItem === item.id
                  ? 'https://api.ccttiot.com/smartmeter/img/static/u4alnzo5240dlVnSQK0r'
                  : 'https://api.ccttiot.com/smartmeter/img/static/uj2puOsyrcZY4ygZL6GX'
              }} 
              style={styles.checkboxImage}
            />
          </TouchableOpacity>
        </View>
      </View>
    </View>
  );

  return (
    <View style={styles.container}>
      <ScrollView style={styles.scrollContent}>
        {carList.map(item => renderCarItem(item))}
      </ScrollView>

      <View style={styles.bottomButtons}>
        <TouchableOpacity onPress={handlePress} style={styles.addButton}>
          <Text style={styles.addButtonText}>+ 添加车辆</Text>
        </TouchableOpacity>
        <TouchableOpacity onPress={handleCancel} style={styles.cancelButton}>
          <Text style={styles.cancelButtonText}>取消</Text>
        </TouchableOpacity>
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#F3FCFF',
  },
  scrollContent: {
    marginBottom: rpx(300),
    flex: 1,
    paddingHorizontal: rpx(20),
    // marginBottom: rpx(160),
  },
  carItem: {
    flexDirection: 'row',
    backgroundColor: '#EEF2FD',
    borderRadius: rpx(20),
    padding: rpx(30),
    marginTop: rpx(20),
    alignItems: 'center',
  },
  marginTop: {
    marginTop: rpx(20),
  },
  leftContent: {
    flex: 1,
    justifyContent: 'center',
  },
  rightContent: {
    alignItems: 'center',
    justifyContent: 'center',
    marginLeft: rpx(20),
  },
  title: {
    fontSize: rpx(40),
    fontWeight: '500',
    color: '#3D3D3D',
    marginBottom: rpx(16),
  },
  subTitle: {
    fontWeight: '500',
    fontSize: rpx(24),
    color: '#3D3D3D',
    marginBottom: rpx(12),
  },
  status: {
    fontSize: rpx(24),
    color: '#666',
    marginBottom: rpx(16),
  },
  tag: {
    alignSelf: 'flex-start',
    paddingVertical: rpx(6),
    paddingHorizontal: rpx(30),
    backgroundColor: '#D2E8FF',
    borderRadius: rpx(29),
    fontSize: rpx(24),
    color: '#4297F3',
    marginTop: rpx(10),
    fontWeight: '500'
  },
  tagShare: {
    color: '#FF9500',
    backgroundColor: '#FFEEDE'
  },
  carImage: {
    width: rpx(232),
    height: rpx(180),
    marginBottom: rpx(16),
  },
  checkboxContainer: {
    width: rpx(44),
    height: rpx(44),
    justifyContent: 'center',
    alignItems: 'center',
  },
  checkboxWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
  },
    checkboxText: {
    fontSize: rpx(32),
    color: '#3D3D3D',
    marginRight: rpx(8),
  },
  checkboxImage: {
    width: rpx(44),
    height: rpx(44),
    resizeMode: 'contain',
  },
  bottomButtons: {
    position: 'absolute',
    bottom: rpx(30),
    left: 0,
    right: 0,
    padding: rpx(20),
    backgroundColor: '#F3FCFF',
  },
  addButton: {
    backgroundColor: '#4297F3',
    height: rpx(92),
    borderRadius: rpx(20),
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom: rpx(20),
  },
  addButtonText: {
    color: '#FFFFFF',
    fontSize: rpx(32),
  },
  cancelButton: {
    backgroundColor: '#fff',
    height: rpx(92),
    borderRadius: rpx(20),
    borderWidth: rpx(2),
    borderColor: '#4297F3',
   
    justifyContent: 'center',
    alignItems: 'center',
  },
  cancelButtonText: {
    color: '#4297F3',
    fontSize: rpx(32),
  },
});